<?php

if (!defined('ABSPATH')) exit;


function elfsight_instashow_add_action_links($links) {
    $links[] = '<a href="' . esc_url(admin_url('admin.php?page=instashow')) . '">Settings</a>';
    $links[] = '<a href="http://codecanyon.net/user/elfsight/portfolio?ref=Elfsight" target="_blank">More plugins by Elfsight</a>';
    return $links;
}
add_filter('plugin_action_links_' . ELFSIGHT_INSTASHOW_PLUGIN_SLUG, 'elfsight_instashow_add_action_links');


function elfsight_instashow_admin_init() {
    wp_register_style('elfsight-instashow-admin', plugins_url('assets/instashow-admin.css', ELFSIGHT_INSTASHOW_FILE), array(), ELFSIGHT_INSTASHOW_VERSION);
    wp_register_script('elfsight-instashow', plugins_url('assets/instashow/dist/jquery.instashow.packaged.js', ELFSIGHT_INSTASHOW_FILE), array('jquery'), ELFSIGHT_INSTASHOW_VERSION);
    wp_register_script('elfsight-instashow-admin', plugins_url('assets/instashow-admin.js', ELFSIGHT_INSTASHOW_FILE), array('jquery', 'elfsight-instashow'), ELFSIGHT_INSTASHOW_VERSION);
}
add_action('admin_init', 'elfsight_instashow_admin_init');

function elfsight_instashow_admin_scripts() {
    wp_enqueue_style('elfsight-instashow-admin');
    wp_enqueue_script('elfsight-instashow');
    wp_enqueue_script('elfsight-instashow-admin');
}

function elfsight_instashow_create_menu() {
    $page_hook = add_menu_page(__('InstaShow', ELFSIGHT_INSTASHOW_TEXTDOMAIN) , __('InstaShow', ELFSIGHT_INSTASHOW_TEXTDOMAIN), 'manage_options', 'instashow', 'elfsight_instashow_settings_page', plugins_url('assets/img/instashow-wp-icon.png', ELFSIGHT_INSTASHOW_FILE));
    add_action('admin_print_styles-' . $page_hook, 'elfsight_instashow_admin_scripts');
}
add_action('admin_menu', 'elfsight_instashow_create_menu');


function elfsight_instashow_underscore_to_cc($l) {
    return strtoupper(substr($l[0], 1));
}


function elfsight_instashow_update_activation_data() {
    if (!wp_verify_nonce($_REQUEST['nonce'], 'elfsight_instashow_update_activation_data_nonce')) {
        exit;
    }

    update_option('elfsight_instashow_purchase_code', !empty($_REQUEST['purchase_code']) ? $_REQUEST['purchase_code'] : '');
    update_option('elfsight_instashow_activated', !empty($_REQUEST['activated']) ? $_REQUEST['activated'] : '');
}
add_action('wp_ajax_elfsight_instashow_update_activation_data', 'elfsight_instashow_update_activation_data');


function elfsight_instashow_update_advanced() {
    if (!wp_verify_nonce($_REQUEST['nonce'], 'elfsight_instashow_update_advanced_nonce')) {
        exit;
    }

    $result = array();

    if (!empty($_REQUEST['custom'])) {
        $type = $_REQUEST['custom'];
        $path = null;

        $uploads_dir_params = wp_upload_dir();
        $uploads_dir = $uploads_dir_params['basedir'] . '/' . ELFSIGHT_INSTASHOW_SLUG;

        switch ($type) {
            case 'css':
                $path = $uploads_dir . '/instashow-custom.css';
                break;

            case 'js':
                $path = $uploads_dir . '/instashow-custom.js';
                break;
        }

        if ($path) {
            if (!is_dir($uploads_dir)) {
              wp_mkdir_p($uploads_dir);
            }

            if (file_exists($path) && !is_writable($path)) {
                $result['success'] = false;
                $result['error'] = __('The file can not be overwritten. Please check the permissions.', ELFSIGHT_INSTASHOW_TEXTDOMAIN);

            } else {
                $result['success'] = true;

                file_put_contents($path, stripslashes($_REQUEST['contents']));
            }
        }
    } else if (!empty($_REQUEST['force_script_add'])) {
        $result['success'] = true;

        update_option('elfsight_instashow_force_script_add',  $_REQUEST['force_script_add']);
    }

    exit(json_encode($result));
}
add_action('wp_ajax_elfsight_instashow_update_advanced', 'elfsight_instashow_update_advanced');

function elfsight_instashow_get_new_version() {
    $latest_version = get_option('elfsight_instashow_lastest_version', '');
    $last_check_datetime = get_option('elfsight_instashow_last_check_datetime', '');

    $result = array();

    if (!empty($last_check_datetime)) {
        $result['message'] = sprintf(__('Last checked on %1$s at %2$s', ELFSIGHT_INSTASHOW_TEXTDOMAIN), date_i18n(get_option('date_format'), $last_check_datetime), date_i18n(get_option('time_format'), $last_check_datetime));
    }

    if (!empty($latest_version) && version_compare(ELFSIGHT_INSTASHOW_VERSION, $latest_version, '<')) {
        $result['version'] = $latest_version;
    }

    die(json_encode($result));
}
add_action('wp_ajax_elfsight_instashow_get_new_version', 'elfsight_instashow_get_new_version');


function elfsight_instashow_settings_page() {
    global $elfsight_instashow_defaults;

    $purchase_code = get_option('elfsight_instashow_purchase_code', '');
    $activated = get_option('elfsight_instashow_activated', '') == 'true';

    $latest_version = get_option('elfsight_instashow_lastest_version', '');
    $last_check_datetime = get_option('elfsight_instashow_last_check_datetime', '');
    $activation_message = get_option('elfsight_instashow_activation_message', '');

    $activation_css_classes = '';
    if ($activated) {
        $activation_css_classes .= 'instashow-admin-activated ';
    }
    else if (!empty($purchase_code)) {
        $activation_css_classes .= 'instashow-admin-activation-invalid ';
    }
    if (!empty($latest_version) && version_compare(ELFSIGHT_INSTASHOW_VERSION, $latest_version, '<')) {
        $activation_css_classes .= 'instashow-admin-activation-has-new-version ';
    }

    $instashow_json = array();

    foreach ($elfsight_instashow_defaults as $name => $val) {
        if ($name == 'source' || $name == 'filter_only' || $name == 'filter_except') {
            $val = array();
        }

        if ($name == 'info' || $name == 'popup_info') {
            $val = explode(', ', $val);
        }

        $instashow_json[preg_replace_callback('/(_.)/', 'elfsight_instashow_underscore_to_cc', $name)] = $val;
    }

    $uploads_dir_params = wp_upload_dir();
    $uploads_dir = $uploads_dir_params['basedir'] . '/' . ELFSIGHT_INSTASHOW_SLUG;

    $custom_css_path = $uploads_dir . '/instashow-custom.css';
    $custom_js_path = $uploads_dir . '/instashow-custom.js';
    $custom_css = is_readable($custom_css_path) ? file_get_contents($custom_css_path) : '';
    $custom_js = is_readable($custom_js_path) ? file_get_contents($custom_js_path) : '';

    $force_script_add = get_option('elfsight_instashow_force_script_add');

    ?><div class="instashow-admin wrap">
        <h2 class="instashow-admin-wp-messages-hack"></h2>
        <div class="instashow-admin-header">
            <div class="instashow-admin-header-support">
                <h4><?php _e('Support', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></h4>

                <div class="instashow-admin-header-support-email">
                    <span class="instashow-admin-icon-email instashow-admin-icon"></span>
                    <a class="instashow-admin-header-support-email-label" href="mailto:support@elfsight.com">support@elfsight.com</a>
                </div>

                <div class="instashow-admin-header-support-comments">
                    <span class="instashow-admin-icon-comments instashow-admin-icon"></span>
                    <a class="instashow-admin-header-support-comments-label" href="http://codecanyon.net/item/instagram-feed-for-wordpress-instashow/13004086/comments?ref=Elfsight" target="_blank">Comments on Codecanyon</a>
                </div>
            </div>

            <a class="instashow-admin-header-logo" href="<?php echo admin_url('admin.php?page=instashow'); ?>" title="<?php _e('InstaShow - WordPress Instagram Gallery Widget', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>">
                <img src="<?php echo plugins_url('assets/img/logo.png', ELFSIGHT_INSTASHOW_FILE); ?>" width="318" height="75" alt="<?php _e('InstaShow - WordPress Instagram Gallery Widget', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>">
            </a>

            <div class="instashow-admin-header-version"><?php _e('version ' . ELFSIGHT_INSTASHOW_VERSION, ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

            <div class="instashow-admin-header-title"><?php _e('WordPress Instagram Gallery Widget', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>
        </div>

        <div class="instashow-admin-demo instashow-admin-block">
            <div class="instashow-admin-block-icon"><span class="instashow-admin-icon-settings instashow-admin-icon"></span></div>

            <div class="instashow-admin-block-inner">
                <div class="instashow-admin-demo-header">
                    <h2><?php _e('Installation', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></h2>
                    <span class="instashow-admin-demo-header-hint"><?php _e('Adjust the widget as you wish, get the shortcode and paste it into any page or post.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                </div>

                <div class="instashow-demo">
                    <form class="instashow-demo-form">
                        <input type="hidden" name="api" value="<?php echo ELFSIGHT_INSTASHOW_API_URL; ?>">
                        <div class="instashow-admin-accordion">
                            <div class="instashow-admin-accordion-item active">
                                <div class="instashow-admin-accordion-item-trigger"><?php _e('Source', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                <div class="instashow-admin-accordion-item-content">
                                    <div class="instashow-demo-source instashow-demo-field-group">
                                        <div class="instashow-demo-field-group-name"><?php _e('Instagram sources', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                        <div class="instashow-demo-field-group-description">
                                            <?php _e('You can add any combination of @username, #hashtag and Instagram photo URL.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <input type="hidden" class="instashow-demo-tags" name="source[]" placeholder="<?php _e('add a source', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>">
                                        </div>
                                    </div>

                                    <div class="instashow-demo-filter instashow-demo-field-group">
                                        <div class="instashow-demo-field-group-name"><?php _e('Filter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                        <div class="instashow-demo-field">
                                            <div class="instashow-demo-field-description">
                                                <?php _e('Filter Instagram photos by setting various conditions. Include or exclude images by using different combinations of @username, #hashtag and photo URL.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                            </div>

                                            <div class="instashow-demo-filter-items">
                                                <template class="instashow-demo-template-filter-item instashow-demo-template">
                                                    <div class="instashow-demo-filter-item">
                                                        <div class="instashow-demo-filter-item-type">
                                                            <select class="instashow-demo-select">
                                                                <option value="filterExcept[]" selected><?php _e('Except', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                                <option value="filterOnly[]"><?php _e('Only', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                            </select>
                                                        </div>

                                                        <div class="instashow-demo-filter-item-input">
                                                            <input type="hidden" class="instashow-demo-tags" name="filterExcept[]" placeholder="<?php _e('add a source', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>">
                                                        </div>

                                                        <div class="instashow-demo-filter-item-remove"></div>
                                                    </div>
                                                </template>
                                            </div>

                                            <button class="instashow-demo-filter-add-item">
                                                <span class="instashow-demo-icon-plus instashow-demo-icon"></span>
                                                <span class="instashow-demo-filter-add-item-label"><?php _e('Add condition', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </button>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-limit instashow-demo-field">
                                            <div class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Limit photos', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                            <div class="instashow-demo-numeric" data-min="0">
                                                <div class="instashow-demo-numeric-decrease"></div>
                                                <input type="text" name="limit" autocomplete="off">
                                                <div class="instashow-demo-numeric-increase"></div>
                                            </div>

                                            <span class="instashow-demo-field-hint"><?php _e('set "0" to show all photos', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-cache instashow-demo-field">
                                            <div class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Cache media time', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                            <span class="instashow-demo-range-container">
                                                <input class="instashow-demo-range-input" type="text" name="cacheMediaTime">
                                                <span class="instashow-demo-range" data-min="0" data-step="100" data-max="86400"></span>
                                            </span>

                                            <span class="instashow-demo-field-hint"><?php _e('s', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="instashow-admin-accordion-item">
                                <div class="instashow-admin-accordion-item-trigger"><?php _e('Sizes', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                <div class="instashow-admin-accordion-item-content">
                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field-group-name">
                                            <?php _e('Widget size', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label class="instashow-demo-width">
                                                <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Width', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                <span class="instashow-demo-range-container">
                                                    <input type="hidden" name="width" value="auto">
                                                    <input class="instashow-demo-range-input" type="text" name="width">
                                                    <span class="instashow-demo-range" data-min="100" data-step="10" data-max="2580"></span>
                                                </span>
                                            </label>

                                            <label class="instashow-demo-width-auto">
                                                <input class="instashow-demo-checkbox" type="checkbox" name="width_auto" value="true">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Responsive', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label class="instashow-demo-height">
                                                <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Height', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                <span class="instashow-demo-range-container">
                                                    <input type="hidden" name="height" value="auto">
                                                    <input class="instashow-demo-range-input" type="text" name="height">
                                                    <span class="instashow-demo-range" data-min="100" data-step="10" data-max="2000"></span>
                                                </span>
                                            </label>

                                            <label class="instashow-demo-height-auto">
                                                <input class="instashow-demo-checkbox" type="checkbox" name="height_auto" value="true">
                                                <span class="instashow-demo-checkbox-label"><?php _e('By content', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field-group-name">
                                            <?php _e('Grid', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                        </div>

                                        <div class="instashow-demo-columns instashow-demo-field">
                                            <label>
                                                <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Columns', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                <div class="instashow-demo-numeric" data-min="1">
                                                    <div class="instashow-demo-numeric-decrease"></div>
                                                    <input type="text" name="columns" autocomplete="off">
                                                    <div class="instashow-demo-numeric-increase"></div>
                                                </div>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-rows instashow-demo-field">
                                            <label>
                                                <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Rows', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                <div class="instashow-demo-numeric" data-min="1">
                                                    <div class="instashow-demo-numeric-decrease"></div>
                                                    <input type="text" name="rows" autocomplete="off">
                                                    <div class="instashow-demo-numeric-increase"></div>
                                                </div>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-gutter instashow-demo-field">
                                            <label>
                                                <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Gutter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                <span class="instashow-demo-range-container">
                                                    <input class="instashow-demo-range-input" type="text" name="gutter">
                                                    <span class="instashow-demo-range" data-min="0" data-max="200"></span>
                                                </span>

                                                <span class="instashow-demo-field-hint"><?php _e('px', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-responsive instashow-demo-field-group">
                                        <input type="hidden" name="responsive" value="">

                                        <div class="instashow-demo-field-group-name">
                                            <?php _e('Responsive breakpoints', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                        </div>

                                        <div class="instashow-demo-field-group-description">
                                            <?php _e('Specify the breakpoints to set the columns, rows and gutter in the grid depending on a window width.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                        </div>

                                        <div class="instashow-demo-responsive-items">
                                            <template class="instashow-demo-template-responsive-item instashow-demo-template">
                                                <div class="instashow-demo-responsive-item">
                                                    <div class="instashow-demo-responsive-item-remove"></div>

                                                    <div class="instashow-demo-field">
                                                        <label>
                                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Window width', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                            <span class="instashow-demo-range-container">
                                                                <input class="instashow-demo-range-input" type="text" name="responsiveWindowWidth">
                                                                <span class="instashow-demo-range" data-min="100" data-step="10" data-max="2580"></span>
                                                            </span>

                                                            <span class="instashow-demo-field-hint"><?php _e('px', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                        </label>
                                                    </div>

                                                    <div class="instashow-demo-responsive-item-columns instashow-demo-field">
                                                        <label>
                                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Columns', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                            <div class="instashow-demo-numeric" data-min="1">
                                                                <div class="instashow-demo-numeric-decrease"></div>
                                                                <input type="text" name="responsiveColumns" autocomplete="off">
                                                                <div class="instashow-demo-numeric-increase"></div>
                                                            </div>
                                                        </label>
                                                    </div>

                                                    <div class="instashow-demo-responsive-item-rows instashow-demo-field">
                                                        <label>
                                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Rows', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                            <div class="instashow-demo-numeric" data-min="1">
                                                                <div class="instashow-demo-numeric-decrease"></div>
                                                                <input type="text" name="responsiveRows" autocomplete="off">
                                                                <div class="instashow-demo-numeric-increase"></div>
                                                            </div>
                                                        </label>
                                                    </div>

                                                    <div class="instashow-demo-responsive-item-gutter instashow-demo-field">
                                                        <label>
                                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Gutter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                                            <span class="instashow-demo-range-container">
                                                                <input class="instashow-demo-range-input" type="text" name="responsiveGutter">
                                                                <span class="instashow-demo-range" data-min="0" data-max="200"></span>
                                                            </span>

                                                            <span class="instashow-demo-field-hint"><?php _e('px', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                        </label>
                                                    </div>
                                                </div>
                                            </template>
                                        </div>

                                        <button class="instashow-demo-responsive-add-item">
                                            <span class="instashow-demo-icon-plus instashow-demo-icon"></span>
                                            <span class="instashow-demo-responsive-add-item-label"><?php _e('Add breakpoint', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                        </button>
                                    </div>
                                </div>
                            </div>

                            <div class="instashow-admin-accordion-item">
                                <div class="instashow-admin-accordion-item-trigger"><?php _e('UI', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                <div class="instashow-admin-accordion-item-content">
                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-controls instashow-demo-field-col-3-4">
                                            <div class="instashow-demo-field">
                                                <div class="instashow-demo-field-name">
                                                    <?php _e('Controls', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                                                </div>

                                                <label class="instashow-demo-controls-item">
                                                    <input type="hidden" name="arrowsControl" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="arrowsControl" value="true">
                                                    <span class="instashow-demo-icon-control-arrows-white instashow-demo-icon-active instashow-demo-icon"></span>
                                                    <span class="instashow-demo-icon-control-arrows-blue instashow-demo-icon"></span>
                                                    <span class="instashow-demo-controls-item-label"><?php _e('Arrows', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>

                                                <label class="instashow-demo-controls-item">
                                                    <input type="hidden" name="scrollControl" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="scrollControl" value="true">
                                                    <span class="instashow-demo-icon-control-scroll-blue instashow-demo-icon"></span>
                                                    <span class="instashow-demo-icon-control-scroll-white instashow-demo-icon-active instashow-demo-icon"></span>
                                                    <span class="instashow-demo-controls-item-label"><?php _e('Scroll', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>

                                                <label class="instashow-demo-controls-item">
                                                    <input type="hidden" name="dragControl" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="dragControl" value="true">
                                                    <span class="instashow-demo-icon-control-drag-white instashow-demo-icon-active instashow-demo-icon"></span>
                                                    <span class="instashow-demo-icon-control-drag-blue instashow-demo-icon"></span>
                                                    <span class="instashow-demo-controls-item-label"><?php _e('Drag', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>
                                            </div>
                                        </div>

                                        <div class="instashow-demo-field-col-1-4">
                                            <div class="instashow-demo-free-mode instashow-demo-field">
                                                <label>
                                                    <input type="hidden" name="freeMode" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="freeMode" value="true">
                                                    <span class="instashow-demo-checkbox-label"><?php _e('Free mode', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>
                                            </div>

                                            <div class="instashow-demo-loop instashow-demo-field">
                                                <label>
                                                    <input type="hidden" name="loop" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="loop" value="true">
                                                    <span class="instashow-demo-checkbox-label"><?php _e('Loop', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>
                                            </div>

                                            <div class="instashow-demo-field">
                                                <label>
                                                    <input type="hidden" name="scrollbar" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="scrollbar" value="true">
                                                    <span class="instashow-demo-checkbox-label"><?php _e('Scrollbar', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field-col-1-2">
                                            <div class="instashow-demo-field">
                                                <div class="instashow-demo-field-name"><?php _e('Direction', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                                <div class="instashow-demo-multiswitch">
                                                    <label class="instashow-demo-multiswitch-item">
                                                        <input type="radio" name="direction" value="horizontal" checked>
                                                        <span class="instashow-demo-icon-direction-horizontal-blue instashow-demo-icon"></span>
                                                        <span class="instashow-demo-icon-direction-horizontal-white instashow-demo-icon-active instashow-demo-icon"></span>
                                                        <span class="instashow-demo-multiswitch-item-label"><?php _e('Horizontal', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                    </label>

                                                    <label class="instashow-demo-multiswitch-item">
                                                        <input type="radio" name="direction" value="vertical">
                                                        <span class="instashow-demo-icon-direction-vertical-blue instashow-demo-icon"></span>
                                                        <span class="instashow-demo-icon-direction-vertical-white instashow-demo-icon-active instashow-demo-icon"></span>
                                                        <span class="instashow-demo-multiswitch-item-label"><?php _e('Vertical', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                    </label>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="instashow-demo-field-col-1-2">
                                            <div class="instashow-demo-auto instashow-demo-field">
                                                <div class="instashow-demo-field-name"><?php _e('Autorotation', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                                <span class="instashow-demo-range-container">
                                                    <input class="instashow-demo-range-input" type="text" name="auto">
                                                    <span class="instashow-demo-range" data-min="0" data-step="100" data-max="10000"></span>
                                                </span>

                                                <span class="instashow-demo-field-hint"><?php _e('ms', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </div>

                                            <div class="instashow-demo-auto-hover-pause instashow-demo-field">
                                                <label>
                                                    <input type="hidden" name="autoHoverPause" value="false">
                                                    <input class="instashow-demo-checkbox" type="checkbox" name="autoHoverPause" value="true">
                                                    <span class="instashow-demo-checkbox-label"><?php _e('Pause on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                </label>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field-col-1-2">
                                            <div class="instashow-demo-field">
                                                <div class="instashow-demo-field-name"><?php _e('Animation effect', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                                <div class="instashow-demo-multiswitch">
                                                    <label class="instashow-demo-multiswitch-item">
                                                        <input type="radio" name="effect" value="slide" checked>
                                                        <span class="instashow-demo-multiswitch-item-label"><?php _e('Slide', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                    </label>

                                                    <label class="instashow-demo-multiswitch-item">
                                                        <input type="radio" name="effect" value="fade">
                                                        <span class="instashow-demo-multiswitch-item-label"><?php _e('Fade', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                                    </label>
                                                </div>
                                            </div>
                                        </div>

                                        <div class="instashow-demo-field-col-1-2">
                                            <div class="instashow-demo-speed instashow-demo-field">
                                                <div class="instashow-demo-field-name"><?php _e('Animation speed', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                                <span class="instashow-demo-range-container">
                                                    <input class="instashow-demo-range-input" type="text" name="speed">
                                                    <span class="instashow-demo-range" data-min="0" data-step="100" data-max="3000"></span>
                                                </span>

                                                <span class="instashow-demo-field-hint"><?php _e('ms', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </div>

                                            <div class="instashow-demo-easing instashow-demo-field">
                                                <div class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Easing', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                                <select class="instashow-demo-select" name="easing">
                                                    <option value="linear"><?php _e('linear', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                    <option value="ease" selected><?php _e('ease', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                    <option value="ease-in"><?php _e('ease-in', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                    <option value="ease-out"><?php _e('ease-out', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                    <option value="ease-in-out"><?php _e('ease-in-out', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                </select>
                                            </div>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-popup-deep-linking instashow-demo-field">
                                            <label>
                                                <input type="hidden" name="popupDeepLinking" value="false">
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupDeepLinking" value="true">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Popup deep linking', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Popup image switch speed', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                            <span class="instashow-demo-range-container">
                                                <input class="instashow-demo-range-input" type="text" name="popupSpeed">
                                                <span class="instashow-demo-range" data-min="0" data-step="100" data-max="3000"></span>
                                            </span>

                                            <span class="instashow-demo-field-hint"><?php _e('ms', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                        </div>

                                        <div class="instashow-demo-popup-easing instashow-demo-field">
                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Popup image switch easing', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                            <select class="instashow-demo-select" name="popupEasing">
                                                <option value="linear"><?php _e('linear', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ease" selected><?php _e('ease', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ease-in"><?php _e('ease-in', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ease-out"><?php _e('ease-out', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ease-in-out"><?php _e('ease-in-out', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                            </select>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field instashow-demo-lang">
                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Language', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                            <select class="instashow-demo-select-language instashow-demo-select" name="lang">
                                                <option value="de"><?php _e('Deutsch', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="en" selected><?php _e('English', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="es"><?php _e('Espa&ntilde;ol', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="fr"><?php _e('Fran&ccedil;ais', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="it"><?php _e('Italiano', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="nl"><?php _e('Nederlands', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="no"><?php _e('Norsk', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="pl"><?php _e('Polski', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="pt-BR"><?php _e('Portugu&ecirc;s', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="sv"><?php _e('Svenska', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="tr"><?php _e('T&uuml;rk&ccedil;e', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ru"><?php _e('&#x0420;&#x0443;&#x0441;&#x0441;&#x043a;&#x0438;&#x0439;', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="hi"><?php _e('&#x939;&#x93F;&#x928;&#x94D;&#x926;&#x940;', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ko"><?php _e('&#xd55c;&#xad6d;&#xc758;', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="zh-HK"><?php _e('&#x4e2d;&#x6587;', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="ja"><?php _e('&#x65e5;&#x672c;&#x8a9e;', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                            </select>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field instashow-demo-mode">
                                            <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Mode', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                            <select class="instashow-demo-select-mode instashow-demo-select" name="mode">
                                                <option value="popup" selected><?php _e('Popup', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                                <option value="instagram"><?php _e('Instagram', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></option>
                                            </select>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="instashow-admin-accordion-item">
                                <div class="instashow-admin-accordion-item-trigger"><?php _e('Info', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                <div class="instashow-admin-accordion-item-content">
                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field-group-name"><?php _e('Gallery Info', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>
                                        <input type="hidden" name="info" value="">

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="info[]" value="likesCounter">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Likes counter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="info[]" value="commentsCounter">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Comments counter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="info[]" value="description">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Description', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>
                                    </div>

                                    <div class="instashow-demo-field-group">
                                        <div class="instashow-demo-field-group-name"><?php _e('Popup Info', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>
                                        <input type="hidden" name="popupInfo" value="">

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="username">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Username', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="instagramLink">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Instagram Link', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="likesCounter">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Likes counter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="commentsCounter">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Comments counter', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="location">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Location', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="passedTime">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Passed time', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="description">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Description', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field">
                                            <label>
                                                <input class="instashow-demo-checkbox" type="checkbox" name="popupInfo[]" value="comments">
                                                <span class="instashow-demo-checkbox-label"><?php _e('Comments', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="instashow-admin-accordion-item">
                                <div class="instashow-admin-accordion-item-trigger"><?php _e('Style', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                <div class="instashow-admin-accordion-item-content">
                                    <div class="instashow-demo-color-scheme instashow-demo-field">
                                        <span class="instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Color scheme:', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>

                                        <select class="instashow-demo-select"></select>
                                    </div>

                                    <div class="instashow-demo-colors">
                                        <div class="instashow-demo-field-group">
                                            <div class="instashow-demo-field-group-name"><?php _e('Gallery Colors:', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryBg">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Background', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryCounters">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Counters', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryDescription">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Description', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryOverlay">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Overlay', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryArrows">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Arrows', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryArrowsHover">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Arrows on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryArrowsBg">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Arrows background', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryArrowsBgHover">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Arrows bg on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryScrollbar">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Scrollbar', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorGalleryScrollbarSlider">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Scrollbar slider', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>

                                        <div class="instashow-demo-field-group">
                                            <div class="instashow-demo-field-group-name"><?php _e('Popup Colors:', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupOverlay">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Overlay', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupBg">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Background', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupUsername">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Username', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupUsernameHover">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Username on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupInstagramLink">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Instagram link', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupInstagramLinkHover">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Instagram link on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupCounters">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Counters', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupPassedTime">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Passed time', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupAnchor">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Anchor', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupAnchorHover">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Anchor on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupText">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Text', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupControls">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Controls', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupControlsHover">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Controls on hover', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupMobileControls">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Mobile controls', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>

                                            <label class="instashow-demo-field">
                                                <input class="instashow-demo-colorpicker" type="text" name="colorPopupMobileControlsBg">
                                                <span class="instashow-demo-colorpicker-label instashow-demo-field-name-inline instashow-demo-field-name"><?php _e('Mobile controls bg', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                                            </label>
                                        </div>
                                    </div>
                                </div>
                            </div>

                            <div class="instashow-demo-shortcode-container instashow-admin-accordion-item-detached instashow-admin-accordion-item">
                                <div class="instashow-admin-accordion-item-trigger"><span class="instashow-admin-icon-shortcode instashow-admin-icon"></span><span><?php _e('Get Shortcode', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span></div>

                                <div class="instashow-admin-accordion-item-content">
                                    <p><?php _e('Copy this shortcode and paste it into any page or post.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></p>
                                    <textarea class="instashow-demo-shortcode" spellcheck="false" readonly></textarea>
                                </div>
                            </div>
                        </div>
                    </form>

                    <div class="instashow-demo-preview-container">
                        <div class="instashow-demo-preview"></div>
                    </div>
                </div>

                <script>
                    function getInstaShowDefaults() {
                        return <?php echo json_encode($instashow_json); ?>;
                    }
                </script>
            </div>
        </div>

        <div class="<?php echo $activation_css_classes; ?>instashow-admin-activation instashow-admin-block">
            <div class="instashow-admin-block-icon">
                <span class="instashow-admin-icon-satellite instashow-admin-icon"></span>
                <span class="instashow-admin-icon-satellite-gif instashow-admin-icon"></span>
            </div>

            <div class="instashow-admin-block-inner">
                <h2><?php _e('Activate InstaShow', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></h2>

                <div class="instashow-admin-activation-advantages">
                    <h3><?php _e('Advantages of Activation', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></h3>
                    <p><?php _e('Quick Support - when your plugin is activated we can reply on your requests faster.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></p>
                    <p><?php _e('Live Updates - easy and fast way to update InstaShow.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></p>
                </div>

                <form class="instashow-admin-activation-form"  data-nonce="<?php echo wp_create_nonce('elfsight_instashow_update_activation_data_nonce'); ?>" data-activation-url="<?php echo ELFSIGHT_INSTASHOW_UPDATE_URL; ?>" data-activation-slug="<?php echo ELFSIGHT_INSTASHOW_SLUG; ?>" data-activation-version="<?php echo ELFSIGHT_INSTASHOW_VERSION; ?>">
                    <input class="instashow-admin-activation-form-activated-input" type="hidden" name="activated" value="<?php echo $activated; ?>">

                    <div class="instashow-admin-activation-form-field">
                        <label>
                            <?php _e('Please enter your CodeCanyon InstaShow Purchase Code', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                            <input class="instashow-admin-activation-form-purchase-code-input" type="text" placeholder="<?php _e('Purchase code', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>" name="purchase_code" value="<?php echo $purchase_code; ?>" class="regular-text" spellcheck="false" autocomplete="off">
                        </label>
                    </div>

                    <div class="instashow-admin-activation-form-message-success instashow-admin-activation-form-message"><?php _e('InstaShow is successfuly activated', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>
                    <div class="instashow-admin-activation-form-message-error instashow-admin-activation-form-message"><?php _e('Your purchase code is not valid', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>
                    <div class="instashow-admin-activation-form-message-fail instashow-admin-activation-form-message"><?php _e('Error occurred while checking your purchase code. Please, contact our support team via <a href="mailto:info@elfsight.com">info@elfsight.com</a>. We apologize for inconveniences.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></div>

                    <div class="instashow-admin-activation-form-field">
                        <button class="instashow-admin-activation-form-activate" type="submit"><?php _e('Activate', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></button>
                    </div>
                </form>

                <div class="instashow-admin-activation-version">
                    <div class="instashow-admin-activation-version-current">
                        <span class="instashow-admin-activation-version-current-label"><?php _e('Current version', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                        <span class="instashow-admin-activation-version-current-value"><?php echo ELFSIGHT_INSTASHOW_VERSION; ?></span>
                    </div>

                    <div class="instashow-admin-activation-version-message-new instashow-admin-activation-version-message">
                        <span class="instashow-admin-icon-info-orange instashow-admin-icon"></span>
                        <span class="instashow-admin-activation-version-message-text"><?php _e('New version is available', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                    </div>

                    <div class="instashow-admin-activation-version-message-latest instashow-admin-activation-version-message">
                        <span class="instashow-admin-icon-info-green instashow-admin-icon"></span>
                        <span class="instashow-admin-activation-version-message-text"><?php _e('You have the latest version', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                    </div>

                    <a class="instashow-admin-activation-version-update-button" href="<?php echo is_multisite() ? network_admin_url('update-core.php') : admin_url('update-core.php'); ?>"><?php _e('Update to', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?> <span class="instashow-admin-activation-version-update-button-version"><?php echo $latest_version; ?></span></a>

                    <div class="instashow-admin-activation-version-check-date">
                        <?php if (!empty($last_check_datetime)) { ?>
                            <?php printf(__('Last checked on %1$s at %2$s', ELFSIGHT_INSTASHOW_TEXTDOMAIN), date_i18n(get_option('date_format'), $last_check_datetime), date_i18n(get_option('time_format'), $last_check_datetime)); ?>
                        <?php } ?>
                    </div>

                    <div class="instashow-admin-activation-version-message-activate instashow-admin-activation-version-message">
                        <span class="instashow-admin-icon-info-red instashow-admin-icon"></span>
                        <span class="instashow-admin-activation-version-message-text"><?php _e('Activate InstaShow for easy and fast updates', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                    </div>
                </div>
            </div>
        </div>

        <div class="instashow-admin-advanced instashow-admin-block" data-nonce="<?php echo wp_create_nonce('elfsight_instashow_update_advanced_nonce'); ?>">
            <div class="instashow-admin-block-icon"><span class="instashow-admin-icon-advanced instashow-admin-icon"></span></div>

            <div class="instashow-admin-block-inner">
                <h2><?php _e('Advanced settings', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></h2>

                <div class="instashow-admin-advanced-option-force-script instashow-admin-advanced-option">
                    <div class="instashow-admin-advanced-option-info">
                        <h3 class="instashow-admin-advanced-option-info-name">
                            <label for="forceScriptAdd"><?php _e('Add InstaShow script to every page', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></label>
                        </h3>

                        <div class="instashow-admin-advanced-option-info-description">
                            <?php _e('By default the plugin adds its scripts only on pages with InstaShow shortcode. This option makes the plugin add scripts on every page.<br>It is useful for ajax websites.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                        </div>
                    </div>

                    <div class="instashow-admin-advanced-option-input">
                        <input type="checkbox" name="force_script_add" value="true" id="forceScriptAdd" class="instashow-admin-advanced-option-input-toggle"<?php echo ($force_script_add === 'on') ? ' checked' : ''?>>
                        <label for="forceScriptAdd"><i></i></label>
                    </div>
                </div>

                <div class="instashow-admin-advanced-delimiter"></div>

                <div class="instashow-admin-advanced-option-css instashow-admin-advanced-option">
                    <div class="instashow-admin-advanced-option-info">
                        <h3 class="instashow-admin-advanced-option-info-name">
                            <?php _e('Custom CSS', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                        </h3>

                        <div class="instashow-admin-advanced-option-info-description">
                            <?php _e('Here you can specify custom styles for InstaShow.<br>It will be printed on each page with the widget.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                        </div>
                    </div>

                    <div class="instashow-admin-advanced-option-editor">
                        <div class="instashow-admin-advanced-option-editor-code" id="instaShowAdvancedSnippetCSS"><?php echo htmlspecialchars($custom_css)?></div>

                        <div class="instashow-admin-advanced-option-editor-controls">
                            <a href="#" data-custom-save="css" class="instashow-admin-activation-form-activate"><?php _e('Save', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></a>

                            <span class="instashow-admin-advanced-option-editor-controls-success">
                                <span class="instashow-admin-icon-success instashow-admin-icon"></span><span><?php _e('Done!', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                            </span>

                            <span class="instashow-admin-advanced-option-editor-controls-error"></span>
                        </div>
                    </div>
                </div>

                <div class="instashow-admin-advanced-delimiter"></div>

                <div class="instashow-admin-advanced-option-js instashow-admin-advanced-option">
                    <div class="instashow-admin-advanced-option-info">
                        <h3 class="instashow-admin-advanced-option-info-name">
                            <?php _e('Custom JavaScript', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                        </h3>

                        <div class="instashow-admin-advanced-option-info-description">
                            <?php _e('Here you can specify custom JS for initiation of InstaShow.<br>This script will be printed on each page with the widget.', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?>
                        </div>
                    </div>

                    <div class="instashow-admin-advanced-option-editor">
                        <div class="instashow-admin-advanced-option-editor-code" id="instaShowAdvancedSnippetJS"><?php echo htmlspecialchars($custom_js) ?></div>

                        <div class="instashow-admin-advanced-option-editor-controls">
                            <a href="#" data-custom-save="js" class="instashow-admin-activation-form-activate"><?php _e('Save', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></a>

                            <span class="instashow-admin-advanced-option-editor-controls-success">
                                <span class="instashow-admin-icon-success instashow-admin-icon"></span><span><?php _e('Done!', ELFSIGHT_INSTASHOW_TEXTDOMAIN); ?></span>
                            </span>

                            <span class="instashow-admin-advanced-option-editor-controls-error"></span>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
<?php } ?>
